This patch adds a keepalive feature to the socket connection, because newer
siemens and benq-siemens phones shutdown GPRS after 30 seconds of inactivity.
	Tomas Janousek <tomi@nomi.cz>

diff -u -r1.3 SocketIrc.java
--- src/jmirc/SocketIrc.java	19 Jan 2006 21:13:38 -0000	1.3
+++ src/jmirc/SocketIrc.java	20 Apr 2006 18:57:58 -0000
@@ -20,6 +20,8 @@
 
 import java.io.*;
 import javax.microedition.io.*;
+import java.util.Timer;
+import java.util.TimerTask;
 
 public class SocketIrc extends IrcConnection {
 	private DataInputStream in;
@@ -30,6 +32,9 @@
 	private int bytein;
 	private int byteout;
 
+	private Timer timer;
+	private KeepAliveTimerTask keepalive;
+
 	public SocketIrc(boolean pollmode, String charset) {
 		encoding = charset;
 
@@ -37,6 +42,9 @@
 		byteout = 0;
 		this.pollmode = pollmode;
 		connected = false;
+
+		timer = new Timer();
+		keepalive = new KeepAliveTimerTask(this);
 	}
 
 	public String connect(String host, int port, String init) {
@@ -52,6 +60,7 @@
 			connected = true;
 			ret = writeData(init);
 
+			timer.schedule(keepalive, 28000, 28000);
 		} catch (Exception e) {
 			ret = "Error trying to connect to IRC server, aborting... ";
 			ret += "Exception: " + e.getMessage();
@@ -145,3 +154,18 @@
 		return byteout;
 	}
 }
+
+class KeepAliveTimerTask extends TimerTask {
+    private SocketIrc irc;
+
+    public KeepAliveTimerTask(SocketIrc irc) {
+	this.irc = irc;
+    }
+
+    public void run() {
+	if (irc.isConnected()) {
+	    irc.writeData("\r\n");
+	} else
+	    this.cancel();
+    }
+}
